==> dtkwidget_2.0.7.2.orig.tar.gz: dtkwidget-2.0.7.2/translations/dtkwidget2_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>Agradecimientos</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 está lanzado bajo %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>Gris oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>Gris claro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>Rojo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>Cian</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>Amarillo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>Rojo oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>Verde oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>Azul oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>Cian oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>Magenta oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>Amarillo oscuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Introduzca un nuevo atajo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
</context>
<context>
    <name>DSimpleListView</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1190"/>
        <source>No search result</source>
        <translation>Sin resultado de búsqueda</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>Restaurar valores predeterminados</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>Ingrese un nuevo atajo</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
</TS>

==> dtkwidget_2.0.9.17.orig.tar.gz: dtkwidget-2.0.9.17/translations/dtkwidget2_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>Agradecimientos</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 está lanzado bajo %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>Gris oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>Gris claro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>Rojo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>Cian</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>Amarillo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>Rojo oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>Verde oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>Azul oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>Cian oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>Magenta oscuro</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>Amarillo oscuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Introduzca un nuevo atajo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1235"/>
        <source>No search result</source>
        <translation>No se encontraron resultados</translation>
    </message>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>Restaurar valores predeterminados</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>Ingrese un nuevo atajo</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
</TS>
